<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.feataholic.com
 * @since      1.0.3 Free
 *
 * @package    MZLDR
 * @subpackage MZLDR/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    MZLDR
 * @subpackage MZLDR/admin
 * @author     Your Name <email@example.com>
 */
class MZLDR_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @var string $plugin_name The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @var string $version The current version of this plugin.
	 */
	private $version;

	/**
	 * The form elements class.
	 *
	 * @var string $form The form elements class.
	 */
	private $form;

	/**
	 * The Loader Model
	 *
	 * @var class $loader_model
	 */
	private $loader_model;

	/**
	 * The Impression Model
	 *
	 * @var class $impression
	 */
	private $impression_model;

	/**
	 * The Statistics Model
	 *
	 * @var class $statistics
	 */
	private $statistics_model;

	/**
	 * Loader Data
	 * 
	 * @var object
	 */
	private $loader_data;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param    string $plugin_name       The name of this plugin.
	 * @param    string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name      = $plugin_name;
		$this->version          = $version;
		$this->form             = new MZLDR_Forms();
		$this->loader_data      = null;
		$this->loader_model     = new MZLDR_Loader_Model();
		$this->impression_model = new MZLDR_Impression_Model();
		$this->statistics_model = new MZLDR_Statistics_Model();

		$this->loader    = array();
		$this->page      = isset( $_GET['page'] ) ? sanitize_key( $_GET['page'] ) : 'dashboard';
		$this->action    = isset( $_GET['action'] ) ? sanitize_key( $_GET['action'] ) : '';
		$this->loader_id = isset( $_GET['loader_id'] ) ? sanitize_key( $_GET['loader_id'] ) : '';
	}

	/**
	 * Runs first on admin init
	 *
	 * @return  void
	 */
	function admin_page_init() {
		if ( $this->page == 'maz-loader' ) {
			// delete loader
			if ( $this->action == 'delete' ) {
				if ( $this->loader_model->delete( $this->loader_id ) ) {
					$this->impression_model->deleteLoaderImpressions( $this->loader_id );
					$notice = __( 'Loader has been deleted.', 'maz-loader' );
					MZLDR_Admin_Notice::add_flash_notice( $notice, 'info' );
				} else {
					$notice = __( 'Loader couldn\'t be deleted.', 'maz-loader' );
					MZLDR_Admin_Notice::add_flash_notice( $notice, 'error' );
				}

				// redirect the user to the appropriate page
				MZLDR_Helper::customAdminRedirect( 'maz-loader-list' );
			} elseif ( $this->action == 'edit' ) {
				$where = array(
					'where' => 'WHERE id=' . $this->loader_id,
					'limit' => 'LIMIT 1',
				);
				$loader = $this->loader_model->getLoaders( $where );

				if ( ! count( $loader ) ) {
					$notice = __( 'Loader does not exist!', 'maz-loader' );
					MZLDR_Admin_Notice::add_flash_notice( $notice, 'error' );
					MZLDR_Helper::customAdminRedirect( 'maz-loader-list' );
				} else {
					$this->loader      = $loader[0];
					$_loader_data      = json_decode( $this->loader->data );
					$loader_appearance = isset( $_loader_data->appearance ) ? $_loader_data->appearance : array();
					$loader_settings   = isset( $_loader_data->settings ) ? $_loader_data->settings : array();
					$loader_custom_code   = isset( $_loader_data->custom_code ) ? $_loader_data->custom_code : array();
					$loader_publish_settings   = isset( $_loader_data->publish_settings ) ? $_loader_data->publish_settings : array();
					
					$loader_data_obj              = new \stdClass();
					$loader_data_obj->appearance  = $loader_appearance;
					$loader_data_obj->settings    = $loader_settings;
					$loader_data_obj->custom_code = $loader_custom_code;
					$loader_data_obj->publish_settings = (array) $loader_publish_settings;

					$this->loader_data = $loader_data_obj;
				}
			}
		} elseif ( $this->page == 'maz-loader-list' ) {
			// update loader publish status
			if ( $this->action == 'update-publish-status' ) {
				$new_status = (bool) isset( $_GET['new_status'] ) ? sanitize_key( $_GET['new_status'] ) : '';

				if ( in_array( (bool) $new_status, array( true, false ) ) ) {
					if ( $this->loader_model->updatePublishStatus( $this->loader_id, $new_status ) ) {
						$notice = __( 'Loader has been updated!', 'maz-loader' );
						MZLDR_Admin_Notice::add_flash_notice( $notice, 'info' );
					} else {
						$notice = __( 'Loader couldn\'t be updated!', 'maz-loader' );
						MZLDR_Admin_Notice::add_flash_notice( $notice, 'error' );
					}

					MZLDR_Helper::customAdminRedirect( 'maz-loader-list' );

				}
			}
		} elseif ( $this->page == 'maz-loader-dashboard' ) {
			$this->statistics = $this->statistics_model->getStatistics();
			$this->statistics = isset( $this->statistics[0] ) ? $this->statistics[0] : array();

			$where = array(
				'order' => 'ORDER BY id DESC',
				'limit' => 'LIMIT 10',
			);
			$this->loaders = $this->loader_model->getLoaders( $where );
		}
	}

	/**
	 * Adds the menu page to the backend
	 *
	 * @return  void
	 */
	function add_menu_page() {
		
		$suffix = '';
		
		
		
		add_menu_page(
			__( 'MAZ Loader - Dashboard', 'maz-loader' ),
			__( 'MAZ Loader', 'maz-loader' ),
			'manage_options',
			'maz-loader-dashboard',
			array( $this, 'maz_loader_dashboard' ),
			plugins_url( 'maz-loader' . $suffix . '/media/admin/img/loader-icon-light.png' ),
			80
		);

		$page_edit_title = ($this->action == 'edit') ? __( 'Edit Loader', 'maz-loader' ) : __( 'Create New Loader', 'maz-loader' );
		
		add_submenu_page(
			'maz-loader-dashboard',
			$page_edit_title,
			__( 'Create New Loader', 'maz-loader' ),
			'manage_options',
			'maz-loader',
			array( $this, 'maz_loader_dashboard' )
		);

		add_submenu_page(
			'maz-loader-dashboard',
			__( 'View Loaders', 'maz-loader' ),
			__( 'View Loaders', 'maz-loader' ),
			'manage_options',
			'maz-loader-list',
			array( $this, 'maz_loader_dashboard' )
		);

		add_submenu_page(
			'maz-loader-dashboard',
			__( 'Settings', 'maz-loader' ),
			__( 'Settings', 'maz-loader' ),
			'manage_options',
			'maz-loader-settings',
			array( $this, 'maz_loader_dashboard' )
		);
	}

	/**
	 * Loads the MAZ Loader Admin Panel
	 *
	 * @return void
	 */
	public function maz_loader_dashboard() {
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/maz-loader-admin.php';
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @return  void
	 */
	public function enqueue_styles() {
		global $pagenow;
		if ( 'admin.php' != $pagenow ) {
			return;
		}

		// Load Google Font
		wp_enqueue_style( $this->plugin_name . '-mazloader-google-font', 'https://fonts.googleapis.com/css?family=Poppins:400,700&display=swap', false );
		// Load the color picker CSS library
		wp_enqueue_style( 'wp-color-picker' );

		
		
		// maz loader CSS library
		wp_enqueue_style( $this->plugin_name . '-mazloader-public', MZLDR_PUBLIC_MEDIA_URL . 'css/mazloader.css', array(), $this->version, 'all' );

		// backend files
		wp_enqueue_style( $this->plugin_name . '-flexboxgrid', MZLDR_ADMIN_MEDIA_URL . 'css/flexboxgrid.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name . '-mazloader-admin-main', MZLDR_ADMIN_MEDIA_URL . 'css/mazloader-admin-main.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @return  void
	 */
	public function enqueue_scripts() {
		global $pagenow;
		if ( 'admin.php' != $pagenow ) {
			return;
		}

		wp_enqueue_media();

		

		wp_enqueue_script( $this->plugin_name . '-front-helper', MZLDR_PUBLIC_MEDIA_URL . 'js/src/mazloader/mazloader-front-helper.js', array( 'wp-color-picker' ), $this->version, true );

		wp_enqueue_script( $this->plugin_name . '-mazloader', MZLDR_ADMIN_MEDIA_URL . 'js/mazloader.js', array( 'wp-color-picker' ), $this->version, false );

		wp_enqueue_script( $this->plugin_name . '-wp-color-picker-alpha', MZLDR_ADMIN_MEDIA_URL . 'js/wp-color-picker-alpha.min.js', array( 'wp-color-picker' ), $this->version, true );

		$this->passLanguageStrings();
		$this->passMAZLoaderJSObject();
	}

	/**
	 * Send some language strings to the front end to use in JS library
	 *
	 * @return  void
	 */
	private function passLanguageStrings() {
		$data = array(
			'duplicate_warning'     => __( 'You are about to duplicate this item. Proceed?', 'maz-loader' ),
			'delete_warning'        => __( 'You are about to delete this item. Proceed?', 'maz-loader' ),
			'media_uploader_title'  => __( 'Choose Image', 'maz-loader' ),
			'media_uploader_button' => __( 'Choose Image', 'maz-loader' ),
			'running'               => __( 'Running...', 'maz-loader' ),
			'shortcode_alert'       => __( 'The Loader\'s shortcode has been copied to your clipboard.', 'maz-loader' ),
		);

		wp_localize_script( $this->plugin_name . '-mazloader', 'mzldr_builder_vars', $data );
	}

	/**
	 * Send the MAZ Loader JS Object
	 *
	 * @return  void
	 */
	private function passMAZLoaderJSObject() {
		$data = array(
			'ADMIN_URL'        => MZLDR_ADMIN_URL,
			'ADMIN_MEDIA_URL'  => MZLDR_ADMIN_MEDIA_URL,
			'PUBLIC_URL'       => MZLDR_PUBLIC_URL,
			'PUBLIC_MEDIA_URL' => MZLDR_PUBLIC_MEDIA_URL,
			'logging_enabled'  => false,
			'editing'          => ( $this->action == 'edit' ) ? 'true' : 'false',
			'ajax_url' 		   => admin_url( 'admin-ajax.php' )
		);

		wp_localize_script( $this->plugin_name . '-mazloader', 'mzldr_js_object', $data );
	}

}
